@@ -94,7 +94,9 @@ class CostReporter(costexplorer.CostExplorer):
             record['AccountId'] = self.account_id
         # Specific to cost_and_usage (CAU)
         record['Granularity'] = self.granularity
-        # Save TimePeriod + RequestId
+        if 'RequestId' in metadata:
+            record['RequestId'] = metadata['RequestId']
+        # Save TimePeriod
         if 'TimePeriod' in record:
             record.update(record['TimePeriod'])
             del record['TimePeriod']
