@@ -14,7 +14,7 @@ CAUGroupBy = typing.List[typing.Dict[typing.Literal['Type', 'Key'], str]]
 
 # Cleanup
 MatchOptions = typing.Literal['EQUALS', 'STARTS_WITH', 'ENDS_WITH', 'CONTAINS', 'CASE_SENSITIVE', 'CASE_INSENSITIVE']
-CAU_RECORD_TYPE = typing.Literal["Credit", "Refund", "Upfront", "Support"]
+# CAU_RECORD_TYPE = typing.Literal["Credit", "Refund", "Upfront", "Support"]
 # RECORD_TYPE_DIMENSIONS = typing.List[typing.Literal["Credit", "Refund", "Upfront", "Support"]]
 
 # Set to Max history time CAU
