@@ -18,7 +18,7 @@ def test_metadata():
     rec = {"TimePeriod": {"Start": "yyyy", "End": "yyyy"}}
     obj = cr.CostReporter()
 
-    cr.AWS_CE_REQUESTID = '1'
+    cr.costexplorer.AWS_CE_REQUESTID = '1'
     obj._stamp_record(rec, {"RequestId": "xxxxx-yyyyy"})
     assert 'Start' in rec
     assert 'End' in rec
